@@ -1,6 +1,7 @@
 <?php
 
-# comment 
+# comment
+// another comment
 
 $number1=123;
 $number2 = 123.45;
@@ -22,8 +23,11 @@ $hash4 = Array(
     'larry' => 'Larry Wall'
 );
 
+$url = "http://www.google.com/";
+
 define( "TEST_CONSTANT", 'NJ and you, perfect together' );
-define( "ANOTHER_CONSTANT",	    "NJ, the garden state" );
+define( "ANOTHER_CONSTANT", "NJ, the garden state" );
+define( "YETANOTHER_CONSTANT", 80 );
 
 $hash5 = Array( 'constant'  => TEST_CONSTANT );
 $array5 = Array( 'test', ANOTHER_CONSTANT );
@@ -31,6 +35,4 @@ $array5 = Array( 'test', ANOTHER_CONSTANT );
 $hash6 =  Array( 'foo' => 'bar', );
 $array6 = Array( 'foo', );
 
-# trailing comma
-
 ?>
